
import React, { useMemo } from 'react';
import { useNavigate } from 'react-router-dom';
import { seoTemplates } from '@/data/seoTemplates';
import { landingPageStructuredData, landingPageBreadcrumbs } from '@/data/structuredData';
import OptimizedPageHelmet from '@/components/common/OptimizedPageHelmet';
import LandingNavbar from '@/components/landing/LandingNavbar';
import HeroSection from '@/components/landing/HeroSection';
import FeaturesSection from '@/components/landing/FeaturesSection';
import PricingSection from '@/components/landing/PricingSection';
import ExploreMoreSection from '@/components/landing/ExploreMoreSection';
import LandingFooter from '@/components/landing/LandingFooter';

const Landing = React.memo(() => {
  const navigate = useNavigate();

  const handleGetStarted = useMemo(() => () => {
    navigate('/dashboard?mode=demo');
  }, [navigate]);

  return (
    <>
      <OptimizedPageHelmet 
        seo={seoTemplates.landing}
        structuredData={landingPageStructuredData}
        preloadImages={[
          'https://ik.imagekit.io/vexorbot/Mobile%20UI.webp?tr=q-85,f-webp',
          'https://ik.imagekit.io/vexorbot/Logo.webp?tr=q-90,f-webp'
        ]}
        prefetchUrls={['/features', '/faq']}
        breadcrumbData={landingPageBreadcrumbs}
      />
      
      <div className="min-h-screen bg-gradient-to-br from-gray-900 via-black to-gray-900 text-white">
        <nav id="navigation" role="navigation" aria-label="Main navigation">
          <LandingNavbar onGetStarted={handleGetStarted} />
        </nav>
        
        <main id="main-content" role="main" className="relative z-10">
          <section aria-label="Hero section with AI trading bot introduction">
            <HeroSection onGetStarted={handleGetStarted} />
          </section>
          
          <section aria-label="AI trading bot features and capabilities">
            <FeaturesSection />
          </section>
          
          <section aria-label="Crypto trading bot pricing plans and subscription options">
            <PricingSection onGetStarted={handleGetStarted} />
          </section>

          <section aria-label="Explore AI trading platform resources and links">
            <ExploreMoreSection />
          </section>
        </main>
        
        <footer role="contentinfo" aria-label="Site footer with links and contact information">
          <LandingFooter />
        </footer>
      </div>
    </>
  );
});

Landing.displayName = 'Landing';

export default Landing;
